# Parrot-Controller
ParrotController is an Olympe wrapper for the Parrot Anafi drone.
This API allows you to connect and interface with the Parrot Anafi;
namely, provides movement and camera functionalities

## Getting Started
Install the library:
1. Clone the repo
  ```sh
  git clone https://github.com/boredbot2/Parrot-Controller.git
  ```
2. Pip install
  ```sh
  pip install ParrotAnafiController
  ```

## Authors
* **[Kevyn Angueira Irizarry](https://github.com/boredbot2)**

